import os
import sys

import click
from zipfile import ZipFile

from askanna.core import client as askanna_client
from askanna.core.utils import get_config

HELP = """
Package downloader, intended for use with runner and unpacks code to /code
"""

SHORT_HELP = "Download package code for AskAnna"


@click.command(help=HELP, short_help=SHORT_HELP)
def cli():
    config = get_config()
    api_server = config["askanna"]["remote"]
    project_suuid = os.getenv("AA_PROJECT_SUUID")
    package_suuid = os.getenv("AA_PACKAGE_SUUID")

    if not project_suuid:
        click.echo("No AA_PROJECT_SUUID found.", err=True)
        sys.exit(1)
    if not package_suuid:
        click.echo("No AA_PACKAGE_SUUID found.", err=True)
        sys.exit(1)

    download_url = "/".join(
        ["project", project_suuid, "packages", package_suuid, "download", ""]
    )
    download_url = api_server + download_url

    r = askanna_client.get(download_url)
    res = r.json()

    r = askanna_client.get(res["target"])
    with open("/tmp/code.zip", "wb") as f:
        f.write(r.content)

    with ZipFile("/tmp/code.zip", "r") as myzip:
        myzip.extractall("/code")



from .base import BaseCLItest


class TestCliLogin(BaseCLItest):
    """
    askanna login

    We expect a login prompt to appear to setup the authentication session
    """
    verb = "login"

    def testCommandLoginBase(self):
        assert "login" in self.result.output
        self.assertIn("login", self.result.output)
        self.assertNotIn("noop", self.result.output)



import os
import click

from askanna.core import client

HELP = """
Download manifest containing the commands for a run
"""

SHORT_HELP = "Download manifest for run"


@click.option(
    "--output", "-o", default="/entrypoint.sh", show_default=True, type=click.Path()
)
@click.command(help=HELP, short_help=SHORT_HELP)
def cli(output):
    api_server = client.config.remote
    run_suuid = os.getenv("AA_RUN_SUUID")

    download_url = "/".join(["runinfo", run_suuid, "manifest", ""])
    download_url = api_server + download_url

    r = client.get(download_url)

    with open(output, "w") as f:
        f.write(r.text)
